@@ -33,7 +33,7 @@ package Apache2::AMFWURFLFilterMemcached;
 
   use vars qw($VERSION);
   my $CommonLib = new Apache2::AMFCommonLib ();
-  $VERSION= "3.21";
+  $VERSION= "3.22";
   my %Capability;
   my %Array_fb;
   my %Array_id;
@@ -372,21 +372,21 @@ sub FallBack {
    foreach $capability (sort keys %Capability) {
         $dummy_id=$idToFind;
         $LOOP=0;
-   		while ($LOOP==0) {   		    
+   		while ($LOOP<2) {   		    
    		    $dummy="$dummy_id|$capability";
         	if ($Array_DDRcapability{$dummy}) {        	  
-        	   $LOOP=1;
+        	   $LOOP=2;
         	   $dummy2="$dummy_id|$capability";
         	   $ArrayCapFoundToPass{$capability}=$Array_DDRcapability{$dummy2};
         	} else {
         	      if ($Array_fb{$dummy_id}) {
-	        	  		$dummy_id=$Array_fb{$dummy_id};        
+	        	  		$dummy_id=$Array_fb{$dummy_id};
         	      } else {
         	         $dummy_id="root";
         	      }
-	        	  if ($dummy_id eq "root" || $dummy_id eq "generic") {
-	        	    $LOOP=1;
-	        	  }
+	              if ($dummy_id eq "root" || $dummy_id eq "generic") {
+	        	    $LOOP++;
+	              }
         	}   
    		}
    		
@@ -502,7 +502,9 @@ sub parseWURFLFile {
 				         my $Array_fullua_id=$ua;
 				         foreach $pair (reverse sort { $a <=> $b }  keys %ParseUA) {
 						 			my $dummy=$ParseUA{$pair};
+							    if ($Array_id{$dummy}) {} else {
 						            $Array_id{$dummy}=$id;
+							    }
 				                $contaUA=$contaUA-1;
 						 }
 				 }
